@@ -728,6 +728,8 @@ class Plinux:
     def cat_file(self, path: str, sudo: bool = False) -> str | dict:
         """Get file content"""
 
+        self.logger.warning(f'Method will be deprecated in the next release. Use .cat()')
+
         cmd = f'cat {path}'
         result = self.run_cmd(cmd, sudo=sudo)
         return result.stdout
@@ -1197,18 +1199,24 @@ class Plinux:
             self.logger.exception(f'Path ({path}) not found or something went wrong.')
             raise err
 
-    def get_directory_size(self, path: str, sudo: bool = False) -> int:
+    def get_dir_size(self, path: str, sudo: bool = False) -> int:
         """Get directory size
 
-        du --block-size=1 --total /mnt/ssd-cache/ | tail -n 1 | cut -f1
+        Command:
+            - du -sh -b /mnt/ssd-cache | awk {'print $1'}
 
-        :param path: /mnt/ssd-cache/
-        :param sudo:
-        :return: Size in bytes
+        Args:
+            path: /mnt/ssd-cache/
+            sudo:
+
+        Returns:
+            Size in bytes
         """
 
-        cmd = f'du --block-size=1 --total {path} | tail -n 1 | cut -f1'
-        result = self.run_cmd(cmd, sudo=sudo).stdout
+        cmd = f"du -sh -b {path} | awk {{'print $1'}}"
+        result = self.run_cmd(cmd, sudo=sudo).stdout  # 876592118	/mnt/ssd-cache/
+        print(result)
+
         try:
             return int(result)
         except TypeError as err:
@@ -1404,6 +1412,7 @@ class Plinux:
         return result
 
     # Aliases
+    cat = cat_file
     ps = get_processes
     ls = list_dir
     cp = copy_file
